@@ -3,6 +3,7 @@ package Catalyst::Component::Implicit;
 use parent qw(Catalyst::Component);
 
 use Catalyst::Utils;
+use MRO::Compat;
 
 sub COMPONENT {
     my ($self, $c, $arguments) = @_; my $class = ref $self || $self;
@@ -10,7 +11,7 @@ sub COMPONENT {
     # Inject an inner package intoto the subclass
     { no strict 'refs'; @{"$class\::Sub::ISA"} = @{"$class\::ISA"} }
 
-    return $self->NEXT::COMPONENT( $c, $arguments );
+    return $self->next::method( $c, $arguments );
 }
 
 1;
